Add chromosome, start information to the homolog data.

add_coord(homolog_df, genes_gr, symbol_colunm_name)

Arguments

homolog_df

A data frame with two columns which contains the homolog pairs.

genes_gr

A GRanges object for genes. It must contain the information for all the homolog ids.

symbol_colunm_name

The column name of gene symbol in 'genes_gr'.

Value

A data frame with annotated homologs.