The best order of the chromosomes decided by the distance matrix. The distance matrix among chromosomes are the count of the homologous
getChrOrders(homolog_df, chrom_infos, method = "TSP")The data.frame with homologous. The output from function subsetHomologsByChrom
A list with the chromosome information data.frame.
a character string with the name of the seriation method or 'spearman' or 'max'. If using 'max', it will try to find the best order by maximal number of homologous for each chromosome pairs. If using 'spearman', it will try to find the best order by the Spearman distance. Otherwise see seriate. It will be worth to try 'TSP' first.
A list with the ordered chromosome names