Retrieve all the gene ranges

getGeneGRs(ids, marts, homologs)

Arguments

ids

A named list with the gene ids for each species

marts

A named list with the Mart object for each species

homologs

A list of homologs. It must be the output from function getHomologGRsl

Value

A list with gene information GRanges.