Retrieve the homolog pairs

getHomologGRs(ids, com_name, marts)

Arguments

ids

A named list with the gene ids for each species

com_name

species abbreviations eg. "hsapiens", "mmusculus", "drerio"

marts

A named list with the Mart object for each species

Value

A list with homolog GRanges.