Plot data by ribbon plot.

orthoRibbonPlot(
  com_name,
  bezier_df,
  chrom_bars_df,
  chrom_label_df,
  symbol_list_top,
  symbol_list_bottom,
  link_lwd = 0.25,
  chr_lwd = 3,
  chr_lineend = "round",
  chr_size = 6,
  label_size = 12,
  symbol_size = 2,
  xlim = c(-0.02, 1.02),
  show_symbol = FALSE
)

Arguments

com_name

Species abbreviations eg. "hsapiens", "mmusculus", "drerio".

bezier_df

A data.frame. The coordinates for Bezier curves. It must have columns "x", "y", "id", and "col". The "id" column saves group id for each pair of homologs.

chrom_bars_df

A data.frame. The coordinates for chromosome line. It must have columns "x", "y", "sp" and "chrom". Here "sp" means species and "chrom" indicates the chromosome.

chrom_label_df

A data.frame. The coordinates for chromosome names. It must have columns "x", "y" and "labels"

symbol_list_top, symbol_list_bottom

The data.frame for the gene labels

The line width for Bezier curve, chromsome bar,

chr_lineend

The line end for chromosome bar.

chr_size, label_size, symbol_size

The size for chromosome label, species, and symbols.

xlim

Two numeric values, specifying the x limit of the scale.

show_symbol

A logical value. Show the symbols or not.

Value

A ggolot object

Examples

# example code