Build the plot data from homolog data.frame, gene annotations and chromosome informations.
buildPlotData(
com_name,
homolog_df,
genes_gr,
chrom_infos,
sp_min_chr_size = 1e+07,
chr_orders = NULL,
filterByCoordSystem = TRUE,
max_links = Inf,
chromosome_order_method = "max"
)Species abbreviations eg. "hsapiens", "mmusculus", "drerio"
The data.frame for homologs with column names "gene_id1", "gene_id2".
A GRanges object for genes. It must contain the information for all the homolog ids. 'gene_name', 'species' must be metadata column name of 'genes_gr'.
A list of chromosome information. The Chromosome information for each species must be a data.frame with columns "name" and "length".
The minimal chromosome size.
Chromosome orders for plot.
Filter the chromosomes or not.
A numeric. The maiximal link number to show in the plot.
A character string with the name of the s eriation method or spearman' or 'max'. If using 'max', it will try to find the best order by maximal number of homologous for each chromosome pairs. If using 'spearman', it will try to find the best order by the Spearman distance. Otherwise see seriate. It will be worth to try 'TSP' first.
A list with elements "homolog_df_list", "chrom_bars_df", "chrom_label_df" , "symbol_list_top" and, "symbol_list_bottom" for plot.
# example code