Retrieve all the gene ranges
getGeneGRs(ids, marts, homologs)A named list with the gene ids for each species
A named list with the Mart object for each species
A list of homologs. It must be the output from function getHomologGRsl
A list with gene information GRanges.