Plot data by ribbon plot.
orthoRibbonPlot(
com_name,
bezier_df,
chrom_bars_df,
chrom_label_df,
symbol_list_top,
symbol_list_bottom,
link_lwd = 0.25,
chr_lwd = 3,
chr_lineend = "round",
chr_size = 6,
label_size = 12,
symbol_size = 2,
xlim = c(-0.02, 1.02),
show_symbol = FALSE
)Species abbreviations eg. "hsapiens", "mmusculus", "drerio".
A data.frame. The coordinates for Bezier curves. It must have columns "x", "y", "id", and "col". The "id" column saves group id for each pair of homologs.
A data.frame. The coordinates for chromosome line. It must have columns "x", "y", "sp" and "chrom". Here "sp" means species and "chrom" indicates the chromosome.
A data.frame. The coordinates for chromosome names. It must have columns "x", "y" and "labels"
The data.frame for the gene labels
The line width for Bezier curve, chromsome bar,
The line end for chromosome bar.
The size for chromosome label, species, and symbols.
Two numeric values, specifying the x limit of the scale.
A logical value. Show the symbols or not.
A ggolot object
# example code